license-info
============

Show list of installed python packages with version and license info. 


Usage
-----

Just install package:

    $ pip install license-info


... and run it:

    $ li


_license-info_ should work properly inside activated virtualenv.

